gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r32832 - in gnunet/src: include topology


From: gnunet
Subject: [GNUnet-SVN] r32832 - in gnunet/src: include topology
Date: Sun, 30 Mar 2014 15:42:47 +0200

Author: bratao
Date: 2014-03-30 15:42:47 +0200 (Sun, 30 Mar 2014)
New Revision: 32832

Modified:
   gnunet/src/include/gnunet_friends_lib.h
   gnunet/src/topology/friends.c
Log:
friend is a reserved work in C++. Rename to friend_id.

Modified: gnunet/src/include/gnunet_friends_lib.h
===================================================================
--- gnunet/src/include/gnunet_friends_lib.h     2014-03-29 15:17:23 UTC (rev 
32831)
+++ gnunet/src/include/gnunet_friends_lib.h     2014-03-30 13:42:47 UTC (rev 
32832)
@@ -33,10 +33,10 @@
  * Signature of a function called on each friend found.
  *
  * @param cls closure
- * @param friend peer identity of the friend
+ * @param friend_id peer identity of the friend
  */
 typedef void (*GNUNET_FRIENDS_Callback)(void *cls,
-                                        const struct GNUNET_PeerIdentity 
*friend);
+                                        const struct GNUNET_PeerIdentity 
*friend_id);
 
 
 /**
@@ -84,12 +84,12 @@
  * Add a friend to the friends file.
  *
  * @param w write handle
- * @param friend friend to add
+ * @param friend_id friend to add
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
 GNUNET_FRIENDS_write (struct GNUNET_FRIENDS_Writer *w,
-                      const struct GNUNET_PeerIdentity *friend);
+                      const struct GNUNET_PeerIdentity *friend_id);
 
 
 #endif

Modified: gnunet/src/topology/friends.c
===================================================================
--- gnunet/src/topology/friends.c       2014-03-29 15:17:23 UTC (rev 32831)
+++ gnunet/src/topology/friends.c       2014-03-30 13:42:47 UTC (rev 32832)
@@ -194,18 +194,18 @@
  * Add a friend to the friends file.
  *
  * @param w write handle
  * @param friend friend to add
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
 GNUNET_FRIENDS_write (struct GNUNET_FRIENDS_Writer *w,
-                      const struct GNUNET_PeerIdentity *friend)
+                      const struct GNUNET_PeerIdentity *friend_id)
 {
   char *buf;
   char *ret;
   size_t slen;
 
-  ret = GNUNET_CRYPTO_eddsa_public_key_to_string (&friend->public_key);
+  ret = GNUNET_CRYPTO_eddsa_public_key_to_string (&friend_id->public_key);
   GNUNET_asprintf (&buf,
                    "%s\n",
                    ret);
@@ -194,18 +194,18 @@
  *
  * @param w write handle
- * @param friend friend to add
+ * @param friend_id friend to add
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */




reply via email to

[Prev in Thread] Current Thread [Next in Thread]